ProSHADE: Class Members

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

Here is a list of all documented class members with links to the class documentation for each member:

### - a -

- aAngle : ProSHADE_internal_data::ProSHADE_data
- addExtraSpace() : ProSHADE_internal_data::ProSHADE_data , ProSHADE_settings
- addStructure() : ProSHADE_settings
- allDetectedCAxes : ProSHADE_settings
- allDetectedDAxes : ProSHADE_settings
- allDetectedIAxes : ProSHADE_settings
- allDetectedOAxes : ProSHADE_settings
- allDetectedTAxes : ProSHADE_settings
- allocateEMatrices() : ProSHADE_internal_data::ProSHADE_data
- allocateRotatedMap() : ProSHADE_internal_spheres::ProSHADE_sphere
- allocateRotatedSHMemory() : ProSHADE_internal_data::ProSHADE_data
- allocateRRPMemory() : ProSHADE_internal_data::ProSHADE_data
- allocateSO3CoeffsSpace() : ProSHADE_internal_data::ProSHADE_data
- allocateWignerMatricesSpace() : ProSHADE_internal_data::ProSHADE_data
- angularDistanceWithBorders() : ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup
- axisErrTolerance : ProSHADE_settings